@@ -2,28 +2,9 @@
 
 import os
 
-from docopt import docopt
-from termcolor import colored
-
 from c10_tools.common import FileProgress, C10
 
 
-def wrapper():
-    print(colored('This will be deprecated in favor of c10 allbus', 'red'))
-    args = docopt('''
-Switch 1553 format 1 messages to indicate the same bus (a or b).
-
-Usage:
-    c10-allbus <src> <dst> [-b] [options]
-
-Options:
-    -b           use the b bus instead of a (default).
-    -f, --force  overwrite existing dst file if present.''')
-
-    for line in main(args):
-        print(line)
-
-
 def main(args):
     """Switch 1553 format 1 messages to indicate the same bus (a or b).
     allbus <src> <dst> [-b] [options]
